Signal to Noise Ratio (SNR)
===========================

.. automodule:: viqa.nr_metrics.snr
    :exclude-members: SNR, signal_to_noise_ratio

   
.. rubric:: Functions

.. currentmodule:: viqa.nr_metrics.snr

.. autosummary::
    :toctree: generated/

    signal_to_noise_ratio


.. rubric:: Classes

.. currentmodule:: viqa.nr_metrics.snr

.. autosummary::
    :toctree: generated/
    :template: class.rst

    SNR